@@ -7,7 +7,7 @@ import shutil
 from newtools.optional_imports import boto3
 from newtools.optional_imports import pandas as pd
 
-from newtools import CSVDoggo, S3Location, log_to_stdout
+from newtools import CSVDoggo, S3Location, log_to_stdout, DoggoFileSystem
 
 from s3fs import S3FileSystem
 
@@ -15,7 +15,7 @@ FpCSVEncodingError = ValueError
 
 logger = log_to_stdout("newtools")
 
-s3_bucket = "newtools-testing"
+s3_bucket = "newtools-tests"
 
 
 class CSVFileTests(unittest.TestCase):
@@ -34,8 +34,10 @@ class CSVFileTests(unittest.TestCase):
         # Upload test data to s3
         cls.s3_base_path = f"s3://{s3_bucket}/{cls.root_prefix}/"
         cls.s3 = S3FileSystem()
-        for file in cls.s3.glob(f"{cls.s3_base_path}*"):
-            cls.s3.rm(file)
+        cls.dfs = DoggoFileSystem()
+        # cls.dfs.rm(f"{cls.s3_base_path}", recursive=True)
+        if cls.dfs.exists(f"{cls.s3_base_path}"):
+            cls.dfs.rm(f"{cls.s3_base_path}", recursive=True)
 
         cls.s3.put(lpath=cls.orig_base_path,
                    rpath=cls.s3_base_path,
@@ -48,8 +50,7 @@ class CSVFileTests(unittest.TestCase):
     @classmethod
     def tearDownClass(cls):
         # Delete uploaded/created files
-        for file in cls.s3.glob(f"{cls.s3_base_path}*"):
-            cls.s3.rm(file)
+        cls.dfs.rm(f"{cls.s3_base_path}", recursive=True)
         shutil.rmtree(cls.local_base_path, ignore_errors=True)
 
     def test_files(self):
@@ -74,7 +75,8 @@ class CSVFileTests(unittest.TestCase):
 
         # Alternate how the path is split
         use_empty_base = True
-
+        if len(files) < 1:
+            raise ValueError('The test data folder is incorrect')
         for file in files:
 
             logger.info("testing file {0}".format(file))
